/** @file
===========================================================================
MODULE          : MultiIOBaseFilter

DESCRIPTIONS    : This base class takes care of doing most of the menial work when writing a transform filter that has multiple input and output pins.

REVISION HISTORY: Version 1.0

COPYRIGHT       : (c)CSIR, Meraka Institute 2007 all rights reserved

RESTRICTIONS		: The information/data/code contained within this file is 
the property of CSIR, Meraka Institute and has been 
classified as PUBLIC.
===========================================================================
*/

#include "MultiIOOutputPin.h"

#include "MultiIOBaseFilter.h"
#include "MultiIOInputPin.h"

CMultiIOOutputPin::CMultiIOOutputPin(CMultiIOBaseFilter* pFilter, CCritSec* pLock, HRESULT* phr, LPCWSTR pName, int nIndex)
: CBaseOutputPin(NAME("TM Multi Output Pin"), pFilter, pLock, phr, pName),
m_pFilter(pFilter),
m_nIndex(nIndex)
{
}

CMultiIOOutputPin::~CMultiIOOutputPin(void)
{
}

HRESULT CMultiIOOutputPin::DecideBufferSize( IMemAllocator* pAlloc, ALLOCATOR_PROPERTIES* pRequestProperties )
{
	//Pass the buffer allocation on to the mixer filter
	return m_pFilter->DecideBufferSize(pAlloc, pRequestProperties, m_nIndex);
}

HRESULT CMultiIOOutputPin::CheckMediaType( const CMediaType* pMediaType )
{
	return m_pFilter->CheckOutputType(pMediaType);
}

HRESULT CMultiIOOutputPin::GetMediaType( int iPosition, CMediaType* pMediaType )
{
	ASSERT(m_pFilter->m_vInputPins.size() > 0);

	//  We don't have any media types if our input is not connected

	if (m_pFilter->m_vInputPins[0]->IsConnected()) 
	{
		return m_pFilter->GetMediaType(iPosition, pMediaType, m_nIndex);
	} else 
	{
		return VFW_S_NO_MORE_ITEMS;
	}
}

STDMETHODIMP CMultiIOOutputPin::Notify( IBaseFilter * pSender, Quality q )
{
	UNREFERENCED_PARAMETER(q);
	UNREFERENCED_PARAMETER(pSender);
	return E_NOTIMPL;
}